vfbLib.parsers.glyph.LinkParser
===============================

.. currentmodule:: vfbLib.parsers.glyph

.. autoclass:: LinkParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~LinkParser.__init__
      ~LinkParser.parse
      ~LinkParser.parse_hex
      ~LinkParser.read_double
      ~LinkParser.read_doubles
      ~LinkParser.read_float
      ~LinkParser.read_floats
      ~LinkParser.read_int16
      ~LinkParser.read_int32
      ~LinkParser.read_int8
      ~LinkParser.read_str
      ~LinkParser.read_str_all
      ~LinkParser.read_uint16
      ~LinkParser.read_uint32
      ~LinkParser.read_uint8
      ~LinkParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~LinkParser.encoding
      ~LinkParser.master_count
      ~LinkParser.stream
      ~LinkParser.ttStemsH_count
      ~LinkParser.ttStemsV_count
   
   